<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:xs="http://www.w3.org/2001/XMLSchema" 
	xmlns:si="http://www.stercomm.com/SI/SI_IE_Resources"
	version="1.0">

<!--
	####################################################################
	## Licensed Materials - Property of IBM
	## (C) Copyright IBM Corp. 2014 All Rights Reserved.
	## US Government Users Restricted Rights - Use, duplication or
	## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
	####################################################################

	This XSLT script is used to migrate SI import files to SPE format
	
	This should be included at the end of the is_si_to_spe.xsl script to filter out 
	SWIFT-specific elements that may have been included in SI import files, but are
	not supported by SPE.
-->

<!-- For ENVELOPE elements - Change Name and Type to Bulk 
     Note: This migration code has been copied from the base file ie_si_to_spe.xsl.
     If any changes are made in the base file, they need to be copied here as well. -->
<xsl:template match="*[local-name()='ENVELOPE' and ./si:STANDARD = 'SWIFT']">
	<xsl:if test="./si:FUNCTION='0'">
		<xsl:element name="ENVELOPE_SWIFT_Bulk_Outbound" namespace="{$spe-namespace}">
			<xsl:apply-templates select="./si:STANDARD"/>
			<xsl:element name="TYPE" namespace="{$spe-namespace}">Bulk</xsl:element>
			<xsl:apply-templates select="./si:FUNCTION"/>
			<xsl:element name="ENVELOPE_COMMON_FIELDS" namespace="{$spe-namespace}">
				<xsl:apply-templates select="./si:NAME"/>
				<xsl:apply-templates select="./si:ENVELOPE_ID"/>
				<xsl:apply-templates select="./si:ENVELOPE_EXTERNAL_ID"/>
				<xsl:apply-templates select="./si:ENVELOPE_VERSION"/>
				<xsl:apply-templates select="./si:SIResourceDefaultVersion"/>
				<xsl:apply-templates select="./si:CONTROL_NUMBER"/>
				<xsl:apply-templates select="./si:SENDER_ID"/>
				<xsl:apply-templates select="./si:RECEIVER_ID"/>
				<xsl:apply-templates select="./si:COMMENTS"/>
				<xsl:apply-templates select="./si:USERNAME"/>
				<xsl:apply-templates select="./si:CREATE_DATE"/>
				<xsl:apply-templates select="./si:USES_GLOBAL_CONTROL_NUMBER"/>
				<xsl:apply-templates select="./si:REFERENCE_ID"/>
			</xsl:element>
			<xsl:apply-templates select="./si:ENVELOPE_PARMS"/>
		</xsl:element>
	</xsl:if>
	<xsl:if test="./si:FUNCTION='1'">
		<xsl:element name="ENVELOPE_SWIFT_Bulk_Inbound" namespace="{$spe-namespace}">
			<xsl:apply-templates select="./si:STANDARD"/>
			<xsl:element name="TYPE" namespace="{$spe-namespace}">Bulk</xsl:element>
			<xsl:apply-templates select="./si:FUNCTION"/>
			<xsl:element name="ENVELOPE_COMMON_FIELDS" namespace="{$spe-namespace}">
				<xsl:apply-templates select="./si:NAME"/>
				<xsl:apply-templates select="./si:ENVELOPE_ID"/>
				<!-- DESCRIPTION will be added as part of ENVELOPE_ID processing -->
				<xsl:apply-templates select="./si:ENVELOPE_EXTERNAL_ID"/>
				<xsl:apply-templates select="./si:ENVELOPE_VERSION"/>
				<xsl:apply-templates select="./si:SIResourceDefaultVersion"/>
				<xsl:apply-templates select="./si:CONTROL_NUMBER"/>
				<xsl:apply-templates select="./si:SENDER_ID"/>
				<xsl:apply-templates select="./si:RECEIVER_ID"/>
				<xsl:apply-templates select="./si:COMMENTS"/>
				<xsl:apply-templates select="./si:USERNAME"/>
				<xsl:apply-templates select="./si:CREATE_DATE"/>
				<xsl:apply-templates select="./si:USES_GLOBAL_CONTROL_NUMBER"/>
				<xsl:apply-templates select="./si:REFERENCE_ID"/>
			</xsl:element>
			<xsl:apply-templates select="./si:ENVELOPE_PARMS"/>			
		</xsl:element>
	</xsl:if>
</xsl:template>
	
<!-- Filter SWIFT_FIN_Inbound parms -->
<xsl:template match ="*[local-name()='ENVELOPE_PARM' and ../../si:STANDARD = 'SWIFT' and ../../si:TYPE = 'FIN' and ../../si:FUNCTION = '1']" >
	<!-- If one of the allowed parms, use conversion template in main ie_si_to_spe.xsl transform -->
	<xsl:if test="(
			./si:NAME = 'AckLookupAlias' or
			./si:NAME = 'APCOrFIN' or
			./si:NAME = 'BP' or
			./si:NAME = 'BPDataExtractMode' or
			./si:NAME = 'BusinessArea' or
			./si:NAME = 'ClosedUserGroup' or
			./si:NAME = 'ComplianceCheckMapName' or
			./si:NAME = 'ControlNumberAge' or
			./si:NAME = 'EnforceMessageSizeLimit' or
			./si:NAME = 'EnvelopeFormat' or
			./si:NAME = 'ErrorBP' or
			./si:NAME = 'ErrorIfBPNotFound' or
			./si:NAME = 'ErrorIfErrorBPNotFound' or
			./si:NAME = 'ErrorIfMapNotFound' or
			./si:NAME = 'ExtractDirectory' or
			./si:NAME = 'ExtractFilename' or
			./si:NAME = 'GenBPNameOpts1' or
			./si:NAME = 'GenBPNameOpts2' or
			./si:NAME = 'GenBPNameOpts3' or
			./si:NAME = 'genbpname_EnvelopeFormat1' or
			./si:NAME = 'genbpname_EnvelopeFormat2' or
			./si:NAME = 'genbpname_EnvelopeFormat3' or
			./si:NAME = 'genbpname_MessageFormat1' or
			./si:NAME = 'genbpname_MessageFormat2' or
			./si:NAME = 'genbpname_MessageFormat3' or
			./si:NAME = 'genbpname_MessageType1' or
			./si:NAME = 'genbpname_MessageType2' or
			./si:NAME = 'genbpname_MessageType3' or
			./si:NAME = 'genbpname_ReceiverID1' or
			./si:NAME = 'genbpname_ReceiverID2' or
			./si:NAME = 'genbpname_ReceiverID3' or
			./si:NAME = 'genbpname_ReceiverIDQual1' or
			./si:NAME = 'genbpname_ReceiverIDQual2' or
			./si:NAME = 'genbpname_ReceiverIDQual3' or
			./si:NAME = 'genbpname_SenderID1' or
			./si:NAME = 'genbpname_SenderID2' or
			./si:NAME = 'genbpname_SenderID3' or
			./si:NAME = 'genbpname_SenderIDQual1' or
			./si:NAME = 'genbpname_SenderIDQual2' or
			./si:NAME = 'genbpname_SenderIDQual3' or
			./si:NAME = 'genbpname_ValidationFlag1' or
			./si:NAME = 'genbpname_ValidationFlag2' or
			./si:NAME = 'genbpname_ValidationFlag3' or
			./si:NAME = 'GenCtrlNumNameOpts1' or
			./si:NAME = 'GenCtrlNumNameOpts2' or
			./si:NAME = 'GenCtrlNumNameOpts3' or
			./si:NAME = 'GenerateAcknowledgement' or
			./si:NAME = 'genctrlnumname_EnvelopeFormat1' or
			./si:NAME = 'genctrlnumname_EnvelopeFormat2' or
			./si:NAME = 'genctrlnumname_EnvelopeFormat3' or
			./si:NAME = 'genctrlnumname_MessageFormat1' or
			./si:NAME = 'genctrlnumname_MessageFormat2' or
			./si:NAME = 'genctrlnumname_MessageFormat3' or
			./si:NAME = 'genctrlnumname_MessageType1' or
			./si:NAME = 'genctrlnumname_MessageType2' or
			./si:NAME = 'genctrlnumname_MessageType3' or
			./si:NAME = 'genctrlnumname_ReceiverID1' or
			./si:NAME = 'genctrlnumname_ReceiverID2' or
			./si:NAME = 'genctrlnumname_ReceiverID3' or
			./si:NAME = 'genctrlnumname_ReceiverIDQual1' or
			./si:NAME = 'genctrlnumname_ReceiverIDQual2' or
			./si:NAME = 'genctrlnumname_ReceiverIDQual3' or
			./si:NAME = 'genctrlnumname_SenderID1' or
			./si:NAME = 'genctrlnumname_SenderID2' or
			./si:NAME = 'genctrlnumname_SenderID3' or
			./si:NAME = 'genctrlnumname_SenderIDQual1' or
			./si:NAME = 'genctrlnumname_SenderIDQual2' or
			./si:NAME = 'genctrlnumname_SenderIDQual3' or
			./si:NAME = 'genctrlnumname_ValidationFlag1' or
			./si:NAME = 'genctrlnumname_ValidationFlag2' or
			./si:NAME = 'genctrlnumname_ValidationFlag3' or
			./si:NAME = 'GenErrorBPNameOpts1' or
			./si:NAME = 'GenErrorBPNameOpts2' or
			./si:NAME = 'GenErrorBPNameOpts3' or
			./si:NAME = 'generrorbpname_EnvelopeFormat1' or
			./si:NAME = 'generrorbpname_EnvelopeFormat2' or
			./si:NAME = 'generrorbpname_EnvelopeFormat3' or
			./si:NAME = 'generrorbpname_MessageFormat1' or
			./si:NAME = 'generrorbpname_MessageFormat2' or
			./si:NAME = 'generrorbpname_MessageFormat3' or
			./si:NAME = 'generrorbpname_MessageType1' or
			./si:NAME = 'generrorbpname_MessageType2' or
			./si:NAME = 'generrorbpname_MessageType3' or
			./si:NAME = 'generrorbpname_ReceiverID1' or
			./si:NAME = 'generrorbpname_ReceiverID2' or
			./si:NAME = 'generrorbpname_ReceiverID3' or
			./si:NAME = 'generrorbpname_ReceiverIDQual1' or
			./si:NAME = 'generrorbpname_ReceiverIDQual2' or
			./si:NAME = 'generrorbpname_ReceiverIDQual3' or
			./si:NAME = 'generrorbpname_SenderID1' or
			./si:NAME = 'generrorbpname_SenderID2' or
			./si:NAME = 'generrorbpname_SenderID3' or
			./si:NAME = 'generrorbpname_SenderIDQual1' or
			./si:NAME = 'generrorbpname_SenderIDQual2' or
			./si:NAME = 'generrorbpname_SenderIDQual3' or
			./si:NAME = 'generrorbpname_ValidationFlag1' or
			./si:NAME = 'generrorbpname_ValidationFlag2' or
			./si:NAME = 'generrorbpname_ValidationFlag3' or
			./si:NAME = 'GenMapNameOpts1' or
			./si:NAME = 'GenMapNameOpts2' or
			./si:NAME = 'GenMapNameOpts3' or
			./si:NAME = 'genmapname_EnvelopeFormat1' or
			./si:NAME = 'genmapname_EnvelopeFormat2' or
			./si:NAME = 'genmapname_EnvelopeFormat3' or
			./si:NAME = 'genmapname_MessageFormat1' or
			./si:NAME = 'genmapname_MessageFormat2' or
			./si:NAME = 'genmapname_MessageFormat3' or
			./si:NAME = 'genmapname_MessageType1' or
			./si:NAME = 'genmapname_MessageType2' or
			./si:NAME = 'genmapname_MessageType3' or
			./si:NAME = 'genmapname_ReceiverID1' or
			./si:NAME = 'genmapname_ReceiverID2' or
			./si:NAME = 'genmapname_ReceiverID3' or
			./si:NAME = 'genmapname_ReceiverIDQual1' or
			./si:NAME = 'genmapname_ReceiverIDQual2' or
			./si:NAME = 'genmapname_ReceiverIDQual3' or
			./si:NAME = 'genmapname_SenderID1' or
			./si:NAME = 'genmapname_SenderID2' or
			./si:NAME = 'genmapname_SenderID3' or
			./si:NAME = 'genmapname_SenderIDQual1' or
			./si:NAME = 'genmapname_SenderIDQual2' or
			./si:NAME = 'genmapname_SenderIDQual3' or
			./si:NAME = 'genmapname_ValidationFlag1' or
			./si:NAME = 'genmapname_ValidationFlag2' or
			./si:NAME = 'genmapname_ValidationFlag3' or
			./si:NAME = 'global_control_no' or
			./si:NAME = 'InvokeBPMode' or
			./si:NAME = 'KeepTranslatedDocument' or
			./si:NAME = 'KeyPart1' or
			./si:NAME = 'KeyPart2' or
			./si:NAME = 'MapNameMode' or
			./si:NAME = 'MaxTransactionControlNumber' or
			./si:NAME = 'MessageCategory' or
			./si:NAME = 'MessageFormat' or
			./si:NAME = 'MessageSizeLimit' or
			./si:NAME = 'MessageType' or
			./si:NAME = 'PerformComplianceCheck' or
			./si:NAME = 'PerformControlNumberSequenceCheck' or
			./si:NAME = 'PerformDuplicateControlNumberCheck' or
			./si:NAME = 'ReceiverIDQual' or
			./si:NAME = 'ReceiverIDType' or
			./si:NAME = 'ReconcileMURWithCN' or
			./si:NAME = 'SenderIDQual' or
			./si:NAME = 'SenderIDType' or
			./si:NAME = 'SpecifiedValidationFlag' or
			./si:NAME = 'StartTransactionControlNumber' or
			./si:NAME = 'TreatAsFileAct' or
			./si:NAME = 'UseBPNameOpts2' or
			./si:NAME = 'UseBPNameOpts3' or
			./si:NAME = 'UseCtrlNumNameOpts2' or
			./si:NAME = 'UseCtrlNumNameOpts3' or
			./si:NAME = 'UseErrorBPNameOpts2' or
			./si:NAME = 'UseErrorBPNameOpts3' or
			./si:NAME = 'UseMapNameOpts2' or
			./si:NAME = 'UseMapNameOpts3' or
			./si:NAME = 'UseWtxComplianceChecking' or
			./si:NAME = 'ValidateDataPDU' or
			./si:NAME = 'ValidateOutput' or
			./si:NAME = 'ValidationFlag' or
			./si:NAME = 'WtxComplianceCheckAmount' or
			./si:NAME = 'WtxComplianceCheckBIC' or
			./si:NAME = 'WtxComplianceCheckCountry' or
			./si:NAME = 'WtxComplianceCheckCurrency' or
			./si:NAME = 'WtxComplianceCheckIBAN'
			
			)">
		<xsl:apply-templates select="." mode="convert"/>
	</xsl:if>
	<xsl:choose>
		<xsl:when test="./si:NAME = 'InvokeErrorBPMode'">
			<xsl:element name="ErrorBPNameMode" namespace="{$spe-namespace}">
				<!-- Just use empty element if this is all whitespace -->
				<xsl:if test="normalize-space(./si:VALUE) != '' and ./si:VALUE != 'SpecifyBP' and ./si:VALUE != 'GenerateBP'">
					<xsl:value-of select="./si:VALUE"/>
				</xsl:if>
				<xsl:if test="./si:VALUE = 'SpecifyBP'">Specify</xsl:if>
				<xsl:if test="./si:VALUE = 'GenerateBP'">Generate</xsl:if>
			</xsl:element>
		</xsl:when>
	</xsl:choose>	
</xsl:template>

<!-- Filter SWIFT_FIN_Outbound parms -->
<xsl:template match ="*[local-name()='ENVELOPE_PARM' and ../../si:STANDARD = 'SWIFT' and ../../si:TYPE = 'FIN' and ../../si:FUNCTION = '0']" >
	<!-- If one of the allowed parms, use conversion template in main ie_si_to_spe.xsl transform -->
	<xsl:if test="(
			./si:NAME = 'AccepterLookupAlias' or
			./si:NAME = 'AckOverdueHours' or
			./si:NAME = 'AckOverdueMinutes' or
			./si:NAME = 'AckOverdueSeconds' or
			./si:NAME = 'AppHdrAddIdentity' or
			./si:NAME = 'AppHdrBizMsgIdr' or
			./si:NAME = 'AppHdrBizSvc' or
			./si:NAME = 'AppHdrCharSet' or
			./si:NAME = 'AppHdrCpyDplct' or
			./si:NAME = 'AppHdrDupInfo' or
			./si:NAME = 'AppHdrDupRef' or
			./si:NAME = 'AppHdrFrom' or
			./si:NAME = 'AppHdrFromID' or
			./si:NAME = 'AppHdrFromType' or
			./si:NAME = 'AppHdrMsgDefIdr' or
			./si:NAME = 'AppHdrMsgName' or
			./si:NAME = 'AppHdrPrty' or
			./si:NAME = 'AppHdrPssblDplct' or
			./si:NAME = 'AppHdrRltd' or
			./si:NAME = 'AppHdrSvcName' or
			./si:NAME = 'AppHdrTo' or
			./si:NAME = 'AppHdrToID' or
			./si:NAME = 'AppHdrToType' or
			./si:NAME = 'BankingPriority' or
			./si:NAME = 'BatchOption' or
			./si:NAME = 'BP' or
			./si:NAME = 'BPDataExtractMode' or
			./si:NAME = 'BusinessArea' or
			./si:NAME = 'ContractID' or
			./si:NAME = 'DeliveryMonitoring' or
			./si:NAME = 'DocumentBatchDelimiter' or
			./si:NAME = 'EnforceMessageSizeLimit' or
			./si:NAME = 'EnvelopeMapName' or
			./si:NAME = 'ErrorBP' or
			./si:NAME = 'ErrorIfBPNotFound' or
			./si:NAME = 'ErrorIfErrorBPNotFound' or
			./si:NAME = 'ErrorIfMapNotFound' or
			./si:NAME = 'ExpectAcknowledgement' or
			./si:NAME = 'ExtractDirectory' or
			./si:NAME = 'ExtractFilename' or
			./si:NAME = 'ExtractMailbox' or
			./si:NAME = 'ExtractMailboxMessageName' or
			./si:NAME = 'GenBPNameOpts1' or
			./si:NAME = 'GenBPNameOpts2' or
			./si:NAME = 'GenBPNameOpts3' or
			./si:NAME = 'genbpname_EnvelopeFormat1' or
			./si:NAME = 'genbpname_EnvelopeFormat2' or
			./si:NAME = 'genbpname_EnvelopeFormat3' or
			./si:NAME = 'genbpname_MessageFormat1' or
			./si:NAME = 'genbpname_MessageFormat2' or
			./si:NAME = 'genbpname_MessageFormat3' or
			./si:NAME = 'genbpname_MessageType1' or
			./si:NAME = 'genbpname_MessageType2' or
			./si:NAME = 'genbpname_MessageType3' or
			./si:NAME = 'genbpname_ReceiverID1' or
			./si:NAME = 'genbpname_ReceiverID2' or
			./si:NAME = 'genbpname_ReceiverID3' or
			./si:NAME = 'genbpname_ReceiverIDQual1' or
			./si:NAME = 'genbpname_ReceiverIDQual2' or
			./si:NAME = 'genbpname_ReceiverIDQual3' or
			./si:NAME = 'genbpname_SenderID1' or
			./si:NAME = 'genbpname_SenderID2' or
			./si:NAME = 'genbpname_SenderID3' or
			./si:NAME = 'genbpname_SenderIDQual1' or
			./si:NAME = 'genbpname_SenderIDQual2' or
			./si:NAME = 'genbpname_SenderIDQual3' or
			./si:NAME = 'genbpname_ValidationFlag1' or
			./si:NAME = 'genbpname_ValidationFlag2' or
			./si:NAME = 'genbpname_ValidationFlag3' or
			./si:NAME = 'GenCtrlNumNameOpts1' or
			./si:NAME = 'GenCtrlNumNameOpts2' or
			./si:NAME = 'GenCtrlNumNameOpts3' or
			./si:NAME = 'genctrlnumname_EnvelopeFormat1' or
			./si:NAME = 'genctrlnumname_EnvelopeFormat2' or
			./si:NAME = 'genctrlnumname_EnvelopeFormat3' or
			./si:NAME = 'genctrlnumname_MessageFormat1' or
			./si:NAME = 'genctrlnumname_MessageFormat2' or
			./si:NAME = 'genctrlnumname_MessageFormat3' or
			./si:NAME = 'genctrlnumname_MessageType1' or
			./si:NAME = 'genctrlnumname_MessageType2' or
			./si:NAME = 'genctrlnumname_MessageType3' or
			./si:NAME = 'genctrlnumname_ReceiverID1' or
			./si:NAME = 'genctrlnumname_ReceiverID2' or
			./si:NAME = 'genctrlnumname_ReceiverID3' or
			./si:NAME = 'genctrlnumname_ReceiverIDQual1' or
			./si:NAME = 'genctrlnumname_ReceiverIDQual2' or
			./si:NAME = 'genctrlnumname_ReceiverIDQual3' or
			./si:NAME = 'genctrlnumname_SenderID1' or
			./si:NAME = 'genctrlnumname_SenderID2' or
			./si:NAME = 'genctrlnumname_SenderID3' or
			./si:NAME = 'genctrlnumname_SenderIDQual1' or
			./si:NAME = 'genctrlnumname_SenderIDQual2' or
			./si:NAME = 'genctrlnumname_SenderIDQual3' or
			./si:NAME = 'genctrlnumname_ValidationFlag1' or
			./si:NAME = 'genctrlnumname_ValidationFlag2' or
			./si:NAME = 'genctrlnumname_ValidationFlag3' or
			./si:NAME = 'GenErrorBPNameOpts1' or
			./si:NAME = 'GenErrorBPNameOpts2' or
			./si:NAME = 'GenErrorBPNameOpts3' or
			./si:NAME = 'generrorbpname_EnvelopeFormat1' or
			./si:NAME = 'generrorbpname_EnvelopeFormat2' or
			./si:NAME = 'generrorbpname_EnvelopeFormat3' or
			./si:NAME = 'generrorbpname_MessageFormat1' or
			./si:NAME = 'generrorbpname_MessageFormat2' or
			./si:NAME = 'generrorbpname_MessageFormat3' or
			./si:NAME = 'generrorbpname_MessageType1' or
			./si:NAME = 'generrorbpname_MessageType2' or
			./si:NAME = 'generrorbpname_MessageType3' or
			./si:NAME = 'generrorbpname_ReceiverID1' or
			./si:NAME = 'generrorbpname_ReceiverID2' or
			./si:NAME = 'generrorbpname_ReceiverID3' or
			./si:NAME = 'generrorbpname_ReceiverIDQual1' or
			./si:NAME = 'generrorbpname_ReceiverIDQual2' or
			./si:NAME = 'generrorbpname_ReceiverIDQual3' or
			./si:NAME = 'generrorbpname_SenderID1' or
			./si:NAME = 'generrorbpname_SenderID2' or
			./si:NAME = 'generrorbpname_SenderID3' or
			./si:NAME = 'generrorbpname_SenderIDQual1' or
			./si:NAME = 'generrorbpname_SenderIDQual2' or
			./si:NAME = 'generrorbpname_SenderIDQual3' or
			./si:NAME = 'generrorbpname_ValidationFlag1' or
			./si:NAME = 'generrorbpname_ValidationFlag2' or
			./si:NAME = 'generrorbpname_ValidationFlag3' or
			./si:NAME = 'GenMapNameOpts1' or
			./si:NAME = 'GenMapNameOpts2' or
			./si:NAME = 'GenMapNameOpts3' or
			./si:NAME = 'genmapname_EnvelopeFormat1' or
			./si:NAME = 'genmapname_EnvelopeFormat2' or
			./si:NAME = 'genmapname_EnvelopeFormat3' or
			./si:NAME = 'genmapname_MessageFormat1' or
			./si:NAME = 'genmapname_MessageFormat2' or
			./si:NAME = 'genmapname_MessageFormat3' or
			./si:NAME = 'genmapname_MessageType1' or
			./si:NAME = 'genmapname_MessageType2' or
			./si:NAME = 'genmapname_MessageType3' or
			./si:NAME = 'genmapname_ReceiverID1' or
			./si:NAME = 'genmapname_ReceiverID2' or
			./si:NAME = 'genmapname_ReceiverID3' or
			./si:NAME = 'genmapname_ReceiverIDQual1' or
			./si:NAME = 'genmapname_ReceiverIDQual2' or
			./si:NAME = 'genmapname_ReceiverIDQual3' or
			./si:NAME = 'genmapname_SenderID1' or
			./si:NAME = 'genmapname_SenderID2' or
			./si:NAME = 'genmapname_SenderID3' or
			./si:NAME = 'genmapname_SenderIDQual1' or
			./si:NAME = 'genmapname_SenderIDQual2' or
			./si:NAME = 'genmapname_SenderIDQual3' or
			./si:NAME = 'genmapname_ValidationFlag1' or
			./si:NAME = 'genmapname_ValidationFlag2' or
			./si:NAME = 'genmapname_ValidationFlag3' or
			./si:NAME = 'global_control_no' or
			./si:NAME = 'IncludeMXAppHeader' or
			./si:NAME = 'IncludePDE' or
			./si:NAME = 'IncludeReceiverFullName' or
			./si:NAME = 'IncludeSenderFullName' or
			./si:NAME = 'IncludeTNG' or
			./si:NAME = 'InvokeBPMode' or
			./si:NAME = 'KeyPart1' or
			./si:NAME = 'KeyPart2' or
			./si:NAME = 'MapName' or
			./si:NAME = 'MapNameMode' or
			./si:NAME = 'MaxTransactionControlNumber' or
			./si:NAME = 'MessageFormat' or
			./si:NAME = 'MessagePriority' or
			./si:NAME = 'MessageSizeLimit' or
			./si:NAME = 'MessageType' or
			./si:NAME = 'MessageUserReferenceOption' or
			./si:NAME = 'MessageUserReferencePDVarname' or
			./si:NAME = 'NRWarning' or
			./si:NAME = 'ObsolesencePeriod' or
			./si:NAME = 'PaymentReleaseInfo' or
			./si:NAME = 'ReceiverBranchInformation' or
			./si:NAME = 'ReceiverCityName' or
			./si:NAME = 'ReceiverCountryCode' or
			./si:NAME = 'ReceiverFinancialInstitution' or
			./si:NAME = 'ReceiverIDQual' or
			./si:NAME = 'ReceiverIDType' or
			./si:NAME = 'ReceiverLocation' or
			./si:NAME = 'ReceiverX1' or
			./si:NAME = 'ReceiverX2' or
			./si:NAME = 'ReceiverX3' or
			./si:NAME = 'ReceiverX4' or
			./si:NAME = 'RequestType' or
			./si:NAME = 'Revision' or
			./si:NAME = 'SenderBranchInformation' or
			./si:NAME = 'SenderCityName' or
			./si:NAME = 'SenderCountryCode' or
			./si:NAME = 'SenderFinancialInstitution' or
			./si:NAME = 'SenderIDQual' or
			./si:NAME = 'SenderIDType' or
			./si:NAME = 'SenderLocation' or
			./si:NAME = 'SenderLogicalTerminal' or
			./si:NAME = 'SenderX1' or
			./si:NAME = 'SenderX2' or
			./si:NAME = 'SenderX3' or
			./si:NAME = 'SenderX4' or
			./si:NAME = 'ServiceCode' or
			./si:NAME = 'ServiceIdentifier' or
			./si:NAME = 'SkipEnveloping' or
			./si:NAME = 'SignDataPDU' or
			./si:NAME = 'SpecifiedValidationFlag' or
			./si:NAME = 'StandardYear' or
			./si:NAME = 'StartTransactionControlNumber' or
			./si:NAME = 'TranslateBeforeEnveloping' or
			./si:NAME = 'TreatAsFileAct' or
			./si:NAME = 'UseBPNameOpts2' or
			./si:NAME = 'UseBPNameOpts3' or
			./si:NAME = 'UseCorrelationOverrides' or
			./si:NAME = 'UseCtrlNumNameOpts2' or
			./si:NAME = 'UseCtrlNumNameOpts3' or
			./si:NAME = 'UseErrorBPNameOpts2' or
			./si:NAME = 'UseErrorBPNameOpts3' or
			./si:NAME = 'UseMapNameOpts2' or
			./si:NAME = 'UseMapNameOpts3' or
			./si:NAME = 'UseMQHADeliveryNotificationReconciliation' or
			./si:NAME = 'UseWtxComplianceChecking' or
			./si:NAME = 'ValidateAddresses' or
			./si:NAME = 'ValidationFlag' or
			./si:NAME = 'WtxComplianceCheckAmount' or
			./si:NAME = 'WtxComplianceCheckBIC' or
			./si:NAME = 'WtxComplianceCheckCountry' or
			./si:NAME = 'WtxComplianceCheckCurrency' or
			./si:NAME = 'WtxComplianceCheckIBAN' or
			./si:NAME = 'XML2AllowModification' or
			./si:NAME = 'XML2CopyService' or
			./si:NAME = 'XML2FileDescription' or
			./si:NAME = 'XML2FileDigestAlgorithm' or
			./si:NAME = 'XML2FileInfo' or
			./si:NAME = 'XML2FileLogicalName' or
			./si:NAME = 'XML2IsNotificationRequested' or
			./si:NAME = 'XML2IsNRRequested' or
			./si:NAME = 'XML2IsPossibleDuplicate' or
			./si:NAME = 'XML2IsSigningRequested' or
			./si:NAME = 'XML2MTAPCOrFIN' or
			./si:NAME = 'XML2MTMessageType' or
			./si:NAME = 'XML2MTClosedUserGroup' or
			./si:NAME = 'XML2PACValue' or
			./si:NAME = 'XML2Priority' or
			./si:NAME = 'XML2ProductName' or
			./si:NAME = 'XML2ProductVersion' or
			./si:NAME = 'XML2RoutingCode' or
			./si:NAME = 'XML2RoutingFunction' or
			./si:NAME = 'XML2RoutingPoint' or
			./si:NAME = 'XML2RoutingStep' or
			./si:NAME = 'XML2Service' or
			./si:NAME = 'XML2StandardYear' or
			./si:NAME = 'XML2TransferDescription' or
			./si:NAME = 'XML2TransferInfo' or
			./si:NAME = 'XML2UseRoutingInstruction' or
			./si:NAME = 'XML2UserPriority' or
			./si:NAME = 'XML2ValidationLevel' or
			./si:NAME = 'XML2ValidationIdentifier' or
			./si:NAME = 'XML2VendorName'
			
			)">
		<xsl:apply-templates select="." mode="convert"/>
	</xsl:if>
	<xsl:choose>
		<xsl:when test="./si:NAME = 'InvokeErrorBPMode'">
			<xsl:element name="ErrorBPNameMode" namespace="{$spe-namespace}">
				<!-- Just use empty element if this is all whitespace -->
				<xsl:if test="normalize-space(./si:VALUE) != '' and ./si:VALUE != 'SpecifyBP' and ./si:VALUE != 'GenerateBP'">
					<xsl:value-of select="./si:VALUE"/>
				</xsl:if>
				<xsl:if test="./si:VALUE = 'SpecifyBP'">Specify</xsl:if>
				<xsl:if test="./si:VALUE = 'GenerateBP'">Generate</xsl:if>
			</xsl:element>
		</xsl:when>
	</xsl:choose>	
</xsl:template>

<!-- 
	SWIFT ENVELOPE_ID processing.  Adds the new envelope DESCRIPTION field as follows:
	Always use MessageType envelope parm
-->
<xsl:template match="*[local-name()='ENVELOPE_ID' and ../si:STANDARD = 'SWIFT']">
	<xsl:element name="ENVELOPE_ID" namespace="{$spe-namespace}">
		<xsl:apply-templates select="@* | node()"/>
	</xsl:element>
	<!-- Add DESCRIPTION.  Use MessageType for both inbound and outbound -->
	<xsl:element name="DESCRIPTION" namespace="{$spe-namespace}" >
		<xsl:value-of select="../si:ENVELOPE_PARMS/si:ENVELOPE_PARM/si:VALUE[../si:NAME/text() = 'MessageType']"/>
	</xsl:element>
</xsl:template>

</xsl:stylesheet>
